@@ -1,5 +1,5 @@
 package Docker::Registry;
-  our $VERSION = '0.05';
+  our $VERSION = '0.06';
 
 1;
 
@@ -38,6 +38,20 @@ This set of modules helps manage that for you.
 Consider this code Alpha quality. It works, but only some read-only methods have been implemented, and the API
 may still change. Be careful if you start depending on this module.
 
+=head1 ATTRIBUTES
+
+=head2 url
+
+The URL of the registry. Most of the time this URL is automatically derived by provider classes 
+like (L<Docker::Registry::ECR>.
+
+=head2 auth
+
+An instance of an object that has the L<Docker::Registry::Auth> Role. See AUTHENTICATION for 
+a list of authentication types. Subclasses (like L<Docker::Registry::GCE>) will set a default
+authentication object appropiate for the specific provider. This is left injectable in the 
+constructor so the programmer can force a specific auth provider.
+
 =head1 METHODS
 
 =head2 repositories
@@ -48,17 +62,33 @@ Returns a L<Docker::Registry::Result::Repositories> object with the list of repo
 
 Returns a L<Docker::Registry::Result::RepositoryTags> object with the list of tags
 
-=head1 AUTHENITCATION
+=head1 PROVIDERS
 
-Each registry class has it's authentication providers. See:
+Different cloud providers of Docker registries have subtle differences between them,
+so there are specialized classes for each supported provider:
 
-L<Docker::Registry::GCE>
+L<Docker::Registry::Azure>
 
 L<Docker::Registry::ECR>
 
+L<Docker::Registry::GCE>
+
 L<Docker::Registry::Gitlab>
 
-for details
+=head1 AUTHENTICATION
+
+Each registry class has it's authentication providers:
+
+L<Docker::Registry::Auth::Basic>
+
+L<Docker::Registry::Auth::ECR>
+
+L<Docker::Registry::Auth::GCEServiceAccount>
+
+L<Docker::Registry::Auth::Gitlab>
+
+The most of the time the specialized provider tries to select the appropiate authentication
+module, but it can be overrided with the C<auth> attribute 
 
 =head1 SEE ALSO
 
@@ -76,9 +106,9 @@ Wesley Schwengle (waterkip) has implemented the GitLab provider, as well as refa
 
 =head1 BUGS and SOURCE
 
-The source code is located here: L<https://github.com/pplu/kubectl-cliwrapper>
+The source code is located here: L<https://github.com/pplu/docker-registry>
 
-Please report bugs to: L<https://github.com/pplu/kubectl-cliwrapper/issues>
+Please report bugs to: L<https://github.com/pplu/docker-registry/issues>
 
 =head1 COPYRIGHT and LICENSE
 
