@@ -1,14 +1,16 @@
 package Docker::Registry::IO::Simple;
-  use Moose;
+  use Moo;
+  use Types::Standard qw/Bool/;
   with 'Docker::Registry::IO';
 
   use HTTP::Tiny;
   use Data::Dumper;
 
-  has debug => (is => 'rw', isa => 'Bool', default => 0);
+  has debug => (is => 'rw', isa => Bool, default => 0);
 
   has ua => (is => 'ro', default => sub {
     HTTP::Tiny->new(
+      max_redirect => 0,
       agent => 'Docker::Registry Perl client' . $Docker::Registry::VERSION,
       timeout => 60,
     );
